==> openGion_dev_5.6.8.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF93S.sql <==
/****************************************************************************/
/* GF93 ( 画面項目ﾘﾝｸ )                                                     */
/*                                                                          */
/* Created : 2013/09/03 10:23:47                                            */
/****************************************************************************/
CREATE TABLE GF93 (
   SYSTEM_ID    varchar           (  10 )                                       /*  10 ｼｽﾃﾑID       */
 , PGID         varchar           (  30 )                   NOT NULL            /*  20 PG-ID        */
 , NMSYORI      varchar           ( 100 )                                       /*  30 処理ｸﾞﾙｰﾌﾟ名 */
 , SEQ          int                             DEFAULT 0   NOT NULL            /*  40 順           */
 , CLM          varchar           (  30 )                                       /*  50 項目         */
 , TO_GAMENID   varchar           (  30 )                                       /*  60 先画面ID     */
 , HREF         varchar           ( 256 )                                       /*  70 ﾘﾝｸ先URL     */
 , TARGET       varchar           (  10 )                                       /*  80 ﾀｰｹﾞｯﾄ       */
 , P_KEYS       varchar           ( 500 )                                       /*  90 引数ｷｰ       */
 , P_VALS       varchar           ( 500 )                                       /* 100 引数値       */
 , USEGAMENID   varchar           (  20 )                                       /* 110 画面使用     */
 , USEREDIRECT  varchar           (  20 )                                       /* 120 ﾘﾀﾞｲﾚｸﾄ使用  */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (   1 )       DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時     */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG       */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG     */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員     */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時     */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG       */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG     */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者       */
);

==> openGion_dev_5.6.9.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF93S.sql <==
/****************************************************************************/
/* GF93 ( 画面項目ﾘﾝｸ )                                                     */
/*                                                                          */
/* Created : 2013/09/30 18:24:55                                            */
/****************************************************************************/
CREATE TABLE GF93 (
   SYSTEM_ID    varchar           (  10 )                                       /*  10 ｼｽﾃﾑID       */
 , PGID         varchar           (  30 )                   NOT NULL            /*  20 PG-ID        */
 , NMSYORI      varchar           ( 100 )                                       /*  30 処理ｸﾞﾙｰﾌﾟ名 */
 , SEQ          int                             DEFAULT 0   NOT NULL            /*  40 順           */
 , CLM          varchar           (  30 )                                       /*  50 項目         */
 , TO_GAMENID   varchar           (  30 )                                       /*  60 先画面ID     */
 , HREF         varchar           ( 256 )                                       /*  70 ﾘﾝｸ先URL     */
 , TARGET       varchar           (  30 )                   NOT NULL            /*  80 ﾀｰｹﾞｯﾄ       */
 , P_KEYS       varchar           ( 500 )                                       /*  90 引数ｷｰ       */
 , P_VALS       varchar           ( 500 )                                       /* 100 引数値       */
 , USEGAMENID   varchar           (  20 )                                       /* 110 画面使用     */
 , USEREDIRECT  varchar           (  20 )                                       /* 120 ﾘﾀﾞｲﾚｸﾄ使用  */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (   1 )       DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時     */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG       */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG     */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員     */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時     */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG       */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG     */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者       */
);
